import QtQuick 1.0

Item{
    signal yesClicked
    signal noClicked

    id: dialog
    width: container.width
    height: container.height
    visible: false
    Rectangle {
        id: dialogOverlay
        width: parent.width
        height: parent.height
        opacity: 0.7
        color: "black"
        MouseArea{
            anchors.fill: parent
        }
    }

    Rectangle{
        anchors.centerIn: dialogOverlay
        width: 350
        height: 200
        color: "gray"
        radius: 10
        border.color: "white"
        border.width: 1
        smooth: true
        Item{
            anchors {top: parent.top; bottom: buttons.top; left: parent.left; right: parent.right}
            Text{
                id: msg
                anchors.centerIn: parent
                font.pixelSize: 16
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
            }
        }

        Item{
            id: buttons
            anchors {bottom: parent.bottom; horizontalCenter: parent.horizontalCenter; bottomMargin: 10}
            height: 50
            width: parent.width - 20
            Rectangle{
                id: yesButton
                anchors {top: parent.top; left: parent.left}
                width: parent.width/2 - 5
                height: parent.height
                radius: 5
                gradient: Gradient{
                    GradientStop{position: 0; color: "lightgray"}
                    GradientStop{position: .5; color: "gray"}
                    GradientStop{position: 1; color: "lightgray"}
                }
                Text{
                    anchors.centerIn: parent
                    color: "white"
                    font.pixelSize: 18
                    font.bold: true
                    text: "Tak"
                }
                MouseArea{
                    anchors.fill: parent
                    onClicked: {
                        dialog.yesClicked();
                        hideDialog();
                    }
                }
            }

            Rectangle{
                id: noButton
                anchors {top: parent.top; right: parent.right}
                width: parent.width/2 - 5
                height: parent.height
                radius: 5
                gradient: Gradient{
                    GradientStop{position: 0; color: "lightgray"}
                    GradientStop{position: .5; color: "gray"}
                    GradientStop{position: 1; color: "lightgray"}
                }
                Text{
                    anchors.centerIn: parent
                    color: "white"
                    font.pixelSize: 18
                    font.bold: true
                    text: "Nie"
                }
                MouseArea{
                    anchors.fill: parent
                    onClicked: {
                        dialog.noClicked();
                        hideDialog();
                    }
                }
            }
        }
    }

    function showDialog(message, yesCallback, noCallback){
        msg.text = message;
        dialog.yesClicked.connect(yesCallback);
        dialog.noClicked.connect(noCallback);
        dialog.visible = true;
    }

    function hideDialog(){
        dialog.yesClicked.disconnect();
        dialog.noClicked.disconnect();
        dialog.visible = false;
    }
}

