import QtQuick 1.0
import "../../js/functions.js" as F

Rectangle{
    property bool soonMode

    height: parent.height

    color: "#000000"

    ListView {
        property bool indexChanging: false
        property bool firstSelect: true

        id: datesList

        anchors {top: parent.top; horizontalCenter: parent.horizontalCenter}
        height: parent.height - selectedDateItem.height
        width: parent.width
        orientation: ListView.Horizontal
        snapMode: ListView.SnapOneItem
        boundsBehavior: Flickable.StopAtBounds
        model: ListModel{id: listModel}
        clip: true
        currentIndex: -1
        z: 0
        delegate: DatePickerDelegate{}
        //highlight: DatePickerHighlight{}

        onCurrentIndexChanged: {

            if (currentIndex !== -1 && currentItem != null){
                console.log(currentIndex)
                indexChanging = true;
                selectedDate.text = currentItem.dateDesc;
                contentX = currentItem.x - datesList.width / 2 + currentItem.width / 2;
                indexChangingTimer.start();
            }
        }
        Timer{
            id: indexChangingTimer
            interval: 400
            onTriggered: {
                datesList.indexChanging = false;
                //if (!datesList.firstSelect){
                    resetEventsSearch();
                //}
                datesList.firstSelect = false;
            }
        }
        Behavior on contentX {enabled: datesList.indexChanging; NumberAnimation { duration: indexChangingTimer.interval; easing.type: Easing.OutBack } }
        Component.onCompleted: {
            if (soonMode){
                var now = new Date();
                var date = F.shiftDate(now, -2);
                listModel.append({
                    weekDay: F.getWeekDayStr(date),
                    monthDay: date.getDate(),
                    date: date,
                    disabled: true
                });
                date = F.shiftDate(now, -1);
                listModel.append({
                    weekDay: F.getWeekDayStr(date),
                    monthDay: date.getDate(),
                    date: date,
                    disabled: true
                });
                listModel.append({
                    weekDay: F.getWeekDayStr(now),
                    monthDay: now.getDate(),
                    date: now,
                    disabled: false
                });
                for (var i = 1; i < 8; ++i){
                    date = F.shiftDate(now, i);
                    listModel.append({
                        weekDay: F.getWeekDayStr(date),
                        monthDay: date.getDate(),
                        date: date,
                        disabled: false
                    });
                }
            } else {
                var now = new Date();
                var date;
                for (var i = -7; i < 0; ++i){
                    date = F.shiftDate(now, i);
                    listModel.append({
                        weekDay: F.getWeekDayStr(date),
                        monthDay: date.getDate(),
                        date: date,
                        disabled: false
                    });
                }
                listModel.append({
                    weekDay: F.getWeekDayStr(now),
                    monthDay: now.getDate(),
                    date: now,
                    disabled: false
                });

                date = F.shiftDate(now, 1);
                listModel.append({
                    weekDay: F.getWeekDayStr(date),
                    monthDay: date.getDate(),
                    date: date,
                    disabled: true
                });
                date = F.shiftDate(now, 2)
                listModel.append({
                    weekDay: F.getWeekDayStr(date),
                    monthDay: date.getDate(),
                    date: date,
                    disabled: true
                });
            }
            currentIndex = -1;
        }

    }

    Rectangle{
        id: selectedDateItem
        color: "grey"
        anchors {top: datesList.bottom; left: parent.left; right: parent.right}
        height: 15
        Text{
            id: selectedDate
            anchors {left: parent.left; verticalCenter: parent.verticalCenter; leftMargin: 5}
            color: "white"
            font {pixelSize: defaultFontSize}
        }
    }

    onVisibleChanged: {
        if (visible){
            if (datesList.currentIndex == -1){
                //reset();
            }
            if (datesList.currentItem){
                datesList.contentX = datesList.currentItem.x - datesList.width / 2 + datesList.currentItem.width / 2;
            } else {
                if (soonMode){
                    datesList.contentX = 0
                } else {
                    datesList.contentX = datesList.contentWidth - datesList.width
                }
            }

        }

    }
    /*
    function clear(){
        datesList.currentIndex = -1;
        listModel.clear();
    }

    function append(el){
        listModel.append(el);
        setCurrentIndex(-1);
    }

    function setCurrentIndex(ind){
        datesList.currentIndex = ind;
    }
    */


    function getCurrentIndex(){
        return datesList.currentIndex;
    }

    function getSelectedDateStr(){
        if (datesList.currentItem){
            return datesList.currentItem.dateStr;
        }
        return null
    }

    function reset(){
        if (soonMode){
            datesList.currentIndex = 2;
        } else {
            datesList.currentIndex = 30;
        }
    }

    function clear(){
        datesList.currentIndex = -1;
        selectedDate.text = ""
    }
}
