import QtQuick 1.0
import ".."
import "EventsView.js" as JS

Item {
    property alias list: eventsList
    property alias model: eventsModel

    height: matchesLists.height
    width: matchesLists.width
    clip: true

    ListView{
        id: eventsList
        anchors.fill: parent
        contentHeight: {
            var h = 0
            for (var k = 0; k < model.count; ++ k){
                var sport = model.get(k)
                h += (sport.tournaments.count - 1) * 5 + 40 + 10
                var matchHeight = sport.sportId === 11 ? 130 : 88
                for (var i = 0; i < sport.tournaments.count; ++ i){
                    var tournament = sport.tournaments.get(i)
                    h += (matchHeight + 2) * tournament.matches.count + (tournament.matches.count - 1) * 5 + 25 + 10
                }
            }
            return h
        }
        //width: parent.width
        clip: true
        delegate: EventsViewDelegate{}
        model: ListModel{id: eventsModel}
        highlightFollowsCurrentItem: false
        boundsBehavior: ListView.StopAtBounds
        //cacheBuffer: 360
        onAtYEndChanged: {
            if (atYEnd){
                if (cacheDown){
                    restoreLowerData()
                } else if (eventsView.pageLength * eventsView.page < eventsView.resultsCount && contentY > 0 && eventsView.pageLoaded){
                    eventsView.pageLoaded = false
                    eventsView.page ++
                    container.getEvents()
                }
            }
        }
        onAtYBeginningChanged: {
            if (atYBeginning && cacheUp){
                restoreUpperData()
            }
        }
        ScrollBar{flickable: eventsList}
    }

    LoadingView{
        id: loadView
        anchors.fill: parent
    }

    Rectangle {
        id: loadViewSmall
        color: "transparent"
        visible: false
        anchors.fill: parent
        AnimatedImage{
            id: img
            anchors.centerIn: parent
            smooth: true
            source: "../../rsc/kreciol_bialy_100x100.gif"
        }
        MouseArea{
            anchors.fill: parent
            onClicked: {}
            onEntered: {}
            onExited: {}
        }
    }

    EmptyDataView{
        id: emptyDataView
        anchors.fill: parent
    }

    Timer{
        id: restoreUpperDataTimer
        interval: 300
        repeat: false
        running: false
        onTriggered: {
            if (dataLocked) return
            var activeList = getActiveList()
            if (!activeList){
                return
            }
            var pageKey = "_"+ pageVisibleEnd
            if (JS.pageSportTournaments[pageKey] === undefined || JS.pageSportTournaments["_"+ (pageVisibleStart - 1)] === undefined){
                return
            }
            console.log("up")
            //activeList.currentIndex = activeList.model.count - 1
            //var lastSection = activeList.currentItem
            //console.log("cacheUp pageKey: "+ pageKey +"; "+ JS.pageSportTournaments[pageKey].length)
            //activeList.positionViewAtIndex ( activeList.model.count - 1, ListView.Beginning )
            for (var j = 0; j < JS.pageSportTournaments[pageKey].length; ++ j){
                remove(activeList.model, activeList.model.count - 1)
                //activeList.positionViewAtIndex ( activeList.model.count - 1, ListView.Beginning )
                /*
                for (var k = 0; k < JS.pageSportTournaments[pageKey][j].tournaments.length; ++ k){
                    if (lastSection.model.count > 0) lastSection.model.remove(lastSection.model.count - 1) // remove tournament
                }
                console.log("cacheUp "+ JS.pageSportTournaments[pageKey][j].tournaments.length +" tournaments removed")
                */
                /*
                if (lastSection.model.count === 0){
                    console.log("cacheUp last section is empty")
                    activeList.model.remove(activeList.model.count - 1) // remove sport
                    activeList.currentIndex = activeList.model.count - 1
                    lastSection = activeList.currentItem
                    console.log("cacheUp last sport removed")
                }
                */
            }

            pageKey = "_"+ (pageVisibleStart - 1)
            //console.log("cacheUp pageKey: "+ pageKey +"; "+ JS.pageSportTournaments[pageKey].length)
            //var heightBefore = activeList.contentHeight
            //var heightAfter
            //activeList.positionViewAtIndex ( 0, ListView.Beginning )
            for (var j = JS.pageSportTournaments[pageKey].length - 1; j >= 0; -- j){
                var sportElem = JS.pageSportTournaments[pageKey][j]
                insertSportAsFirst(sportElem, activeList.model)

                /*
                var sportId = JS.pageSportTournaments[pageKey][j].sportId
                var sportIndex = JS.sportsIndexes["_"+ sportId]
                activeList.currentIndex = sportIndex
                var sportSection = activeList.currentItem
                var tournaments = JS.pageSportTournaments[pageKey][j].tournaments
                for (var k = tournaments.length - 1; k >= 0; -- k){
                    sportSection.model.insert(0, tournaments[k])
                }
                console.log("cacheUp "+ tournaments.length +" tournaments added")
                */
                /*
                if (activeList.model.get(0).sportId == JS.pageSportTournaments[pageKey][j].sportId){
                    activeList.currentIndex = 0
                    var firstSection = activeList.currentItem
                    var tournaments = JS.pageSportTournaments[pageKey][j].tournaments
                    for (var k = tournaments.length - 1; k >= 0; -- k){
                        firstSection.model.insert(0, tournaments[k])
                    }
                    console.log("cacheUp "+ tournaments.length +" tournaments added")
                } else {
                    var sportElem = JS.pageSportTournaments[pageKey][j].sport
                    insertSportAsFirst(sportElem, activeList.model)
                    console.log("cacheUp sport added with "+ sportElem.tournaments.length +" tournaments")
                }
                */
            }




            activeList.positionViewAtIndex ( JS.pageSportTournaments["_"+ (pageVisibleStart - 1)].length, ListView.Beginning )

            //heightAfter = activeList.contentHeight

            //activeList.contentY += heightAfter - heightBefore

            pageVisibleEnd --
            pageVisibleStart --
            if (pageVisibleStart == 1){
                cacheUp = false
            }
            cacheDown = true
            showList()
        }
    }

    Timer{
        id: restoreLowerDataTimer
        interval: 300
        repeat: false
        running: false
        onTriggered: {
            if (dataLocked) return
            var activeList = getActiveList()
            if (!activeList){
                return
            }
            var pageKey = "_"+ pageVisibleStart
            if (JS.pageSportTournaments[pageKey] === undefined || JS.pageSportTournaments["_"+ (pageVisibleEnd + 1)] === undefined){
                return
            }
            console.log("down")
            //activeList.currentIndex = 0
            //var firstSection = activeList.currentItem
            //console.log("cacheDown pageKey: "+ pageKey +"; "+ JS.pageSportTournaments[pageKey].length)
            for (var j = 0; j < JS.pageSportTournaments[pageKey].length; ++ j){
                remove(activeList.model, 0)
                /*
                for (var k = 0; k < JS.pageSportTournaments[pageKey][j].tournaments.length; ++ k){
                    if (firstSection.model.count > 0) firstSection.model.remove(0) // remove tournament
                }
                console.log("cacheDown "+ JS.pageSportTournaments[pageKey][j].tournaments.length +" tournaments removed")
                */
                /*
                if (firstSection.model.count === 0){
                    console.log("cacheDown first section is empty")
                    activeList.model.remove(0) // remove sport
                    activeList.currentIndex = 0
                    firstSection = activeList.currentItem
                    //heightAfter -= heightBefore
                    //heightBefore += firstSection.list.height
                    console.log("cacheDown first sport removed")
                }
                */
            }

            pageKey = "_"+ (pageVisibleEnd + 1)
            //console.log("cacheDown pageKey: "+ pageKey +"; "+ JS.pageSportTournaments[pageKey].length)
            for (var j = 0; j < JS.pageSportTournaments[pageKey].length; ++ j){
                var sportElem = JS.pageSportTournaments[pageKey][j]
                appendSport(sportElem, activeList.model)
                /*
                var sportId = JS.pageSportTournaments[pageKey][j].sportId
                var sportIndex = JS.sportsIndexes["_"+ sportId]
                activeList.currentIndex = sportIndex
                var sportSection = activeList.currentItem
                var tournaments = JS.pageSportTournaments[pageKey][j].tournaments
                for (var k = 0; k < tournaments.length - 1; ++ k){
                    sportSection.model.append(tournaments[k])
                }
                console.log("cacheDown "+ tournaments.length +" tournaments added")
                */
                /*
                if (activeList.model.get(activeList.model.count - 1).sportId == JS.pageSportTournaments[pageKey][j].sportId){
                    activeList.currentIndex = activeList.model.count - 1
                    var lastSection = activeList.currentItem
                    var tournaments = JS.pageSportTournaments[pageKey][j].tournaments
                    for (var k = 0; k < tournaments.length - 1; ++ k){
                        lastSection.model.append(tournaments[k])
                    }
                    console.log("cacheDown "+ tournaments.length +" tournaments added")
                } else {
                    var sportElem = JS.pageSportTournaments[pageKey][j].sport
                    appendSport(sportElem, activeList.model)
                    console.log("cacheDown sport added with "+ sportElem.tournaments.length +" tournaments")
                }
                */
            }


            //var heightBefore = activeList.contentHeight
            //var heightAfter



            //heightAfter = activeList.contentHeight
            //activeList.contentY -= heightAfter - heightBefore
            activeList.positionViewAtIndex ( activeList.model.count - JS.pageSportTournaments[pageKey].length - 1, ListView.End )
            pageVisibleStart ++
            pageVisibleEnd ++
            if (pageVisibleEnd == page){
                cacheDown = false
            }
            cacheUp = true
            showList()
        }
    }

    function showLoadView(){
        eventsList.visible = false
        emptyDataView.visible = false
        loadViewSmall.visible = false
        loadView.visible = true
    }

    function showSmallLoadView(){
        emptyDataView.visible = false
        loadView.visible = false
        loadViewSmall.visible = true
    }

    function showEmptyDataView(){
        eventsList.visible = false
        loadView.visible = false
        loadViewSmall.visible = false
        emptyDataView.visible = true
    }

    function hideLoadView(){
        loadView.visible = false
    }

    function hideSmallLoadView(){
        loadViewSmall.visible = false
    }

    function showList(){
        hideLoadView()
        hideSmallLoadView()
        emptyDataView.visible = false
        eventsList.visible = true
    }

    function restoreUpperData(){
        if (!dataLocked && !restoreUpperDataTimer.running && !restoreLowerDataTimer.running && cacheUp){
            showSmallLoadView()
            restoreUpperDataTimer.start()
        }
    }

    function restoreLowerData(){
        if (!dataLocked && !restoreUpperDataTimer.running && !restoreLowerDataTimer.running && cacheDown){
            showSmallLoadView()
            restoreLowerDataTimer.start()
        }
    }
}
