import QtQuick 1.0
import ".."
import "live"
import "scores"
import "soon"
import "EventsView.js" as JS

RightView{

    property int page: 1
    property int pageVisibleStart: 1
    property int pageVisibleEnd: 1
    property bool cacheUp: false
    property bool cacheDown: false
    property bool pageLoaded: true
    property int pageLength: 5
    property int resultsCount: -1

    property int sectionsCount: -1
    property int lastSportId: -1

    property bool dataLocked: false

    color: "white"
    radius: 5
    scale: 1

    TopBar{id: topBar}

    Item{
        id: matchesLists
        anchors {top: topBar.bottom; left: parent.left; right: parent.right; bottom: parent.bottom; topMargin: 5}

        Component{
            id: basketballDelegateLive
            BasketballMatchLive{}
        }
        Component{
            id: f1DelegateLive
            F1RaceLive{}
        }
        Component{
            id: footballDelegateLive
            FootballMatchLive{}
        }
        Component{
            id: handballDelegateLive
            HandballMatchLive{}
        }
        Component{
            id: hockeyDelegateLive
            HockeyMatchLive{}
        }
        Component{
            id: tenisDelegateLive
            TenisMatchLive{}
        }
        Component{
            id: basketballDelegateScores
            BasketballMatchScores{}
        }
        Component{
            id: f1DelegateScores
            F1RaceScores{}
        }
        Component{
            id: footballDelegateScores
            FootballMatchScores{}
        }
        Component{
            id: handballDelegateScores
            HandballMatchScores{}
        }
        Component{
            id: hockeyDelegateScores
            HockeyMatchScores{}
        }
        Component{
            id: tenisDelegateScores
            TenisMatchScores{}
        }
        Component{
            id: basketballDelegateSoon
            BasketballMatchSoon{}
        }
        Component{
            id: f1DelegateSoon
            F1RaceSoon{}
        }
        Component{
            id: footballDelegateSoon
            FootballMatchSoon{}
        }
        Component{
            id: handballDelegateSoon
            HandballMatchSoon{}
        }
        Component{
            id: hockeyDelegateSoon
            HockeyMatchSoon{}
        }
        Component{
            id: tenisDelegateSoon
            TenisMatchSoon{}
        }

        Row{
            property variant activeList

            id: lists
            height: matchesLists.height
            Behavior on x { NumberAnimation { duration: 200; easing.type: Easing.InOutCubic } }
            states: [
                State{
                    name: "LIVE"
                    when: topBar.state == "LIVE"
                    PropertyChanges { target: lists; x: 0; activeList: liveList}
                },
                State{
                    name: "SCORES"
                    when: topBar.state == "SCORES"
                    PropertyChanges { target: lists; x: - matchesLists.width; activeList: scoresList}
                },
                State{
                    name: "SOON"
                    when: topBar.state == "SOON"
                    PropertyChanges { target: lists; x: - matchesLists.width * 2; activeList: soonList}
                },
                State{
                    name: "LOADER"
                    when: topBar.state != "LIVE" && topBar.state != "SCORES" && topBar.state != "SOON"
                    PropertyChanges { target: lists; x: - matchesLists.width * 3}
                }
            ]

            EventsContent{
                id: liveList
            }

            EventsContent{
                id: scoresList
            }

            EventsContent{
                id: soonList
            }

            Item {
                id: load
                height: matchesLists.height
                width: matchesLists.width
                clip: true
                LoadingView{
                    id: loadView
                    anchors.fill: parent
                    visible: true
                }
            }
        }

    }

    function showLoadView(){
        if (lists.activeList) lists.activeList.showLoadView()
    }

    function showSmallLoadView(){
        if (lists.activeList) lists.activeList.showSmallLoadView()
    }

    function showEmptyDataView(){
        if (lists.activeList) lists.activeList.showEmptyDataView()
    }

    function showList(){
        if (lists.activeList) lists.activeList.showList()
    }

    function hideLoadView(){
        if (lists.activeList) lists.activeList.hideLoadView()
    }

    function hideSmallLoadView(){
        if (lists.activeList) lists.activeList.hideLoadView()
    }

    function getDelegate(sportId){
        if (topBar.state === 'LIVE'){
            switch (sportId){
                case 1: // football
                    return footballDelegateLive
                case 2: // basketball
                    return basketballDelegateLive
                case 4: // hockey
                    return hockeyDelegateLive
                case 5: // tenis
                    return tenisDelegateLive
                case 6: // handball
                    return handballDelegateLive
                case 11: // f1
                    return f1DelegateLive
            }
        } else if (topBar.state === 'SCORES'){
            switch (sportId){
                case 1: // football
                    return footballDelegateScores
                case 2: // basketball
                    return basketballDelegateScores
                case 4: // hockey
                    return hockeyDelegateScores
                case 5: // tenis
                    return tenisDelegateScores
                case 6: // handball
                    return handballDelegateScores
                case 11: // f1
                    return f1DelegateScores
            }
        } else if (topBar.state === 'SOON'){
            switch (sportId){
                case 1: // football
                    return footballDelegateSoon
                case 2: // basketball
                    return basketballDelegateSoon
                case 4: // hockey
                    return hockeyDelegateSoon
                case 5: // tenis
                    return tenisDelegateSoon
                case 6: // handball
                    return handballDelegateSoon
                case 11: // f1
                    return f1DelegateSoon
            }
        }
        return null
    }

    function getTournamentElem(tournament){
        var tournamentElem = {}
        tournamentElem.tournamentId = tournament.tournament_id
        tournamentElem.tournamentName = tournament.tournament_name.split('/').join(' / ').split('-').join(' - ')
        tournamentElem.matches = []
        var matches = tournament.entries.entry;
        for (var m in matches){
            var match = matches[m];
            var teams = match.entries.entry;
            var date = match.match_date.substring(0, 10)
            var time = match.match_date.substring(match.match_date.length - 8, match.match_date.length - 3)
            var matchName = match.match_name ? match.match_name.split('/').join(' / ').split('-').join(' - ') : ''
            //var matchDelegate = getDelegate(sport.sport_id)
            //console.log(matchDelegate)
            var matchElem = {
                matchId: match.match_id,
                tournament: tournament.tournament_name,
                tournamentId: tournament.tournament_id,
                statusAndTime: match.status_name +' - '+ time,
                time: time,
                date: date,
                timeAndDate: date +' '+ time,
                status: match.status_name,
                teamName1: teams !== undefined ? (teams[0].team_name.split('/').join(' / ').split('-').join(' - ')) : null,
                logo1: teams !== undefined ? ((teams[0].team_img !== undefined && teams[0].team_img !== '') ? getImgURL(teams[0].team_img) : '') : null,
                teamName2: teams !== undefined ? (teams[1].team_name.split('/').join(' / ').split('-').join(' - ')) : null,
                logo2: teams !== undefined ? ((teams[1].team_img !== undefined && teams[1].team_img !== '') ? getImgURL(teams[1].team_img) : '') : null,
                score: teams !== undefined ? ((teams[0].current +':'+ teams[1].current)) : null,
                comments: match.match_comment == 1,
                set1Value1: teams !== undefined ? (teams[0].period1) : null,
                set2Value1: teams !== undefined ? (teams[0].period2) : null,
                set3Value1: teams !== undefined ? (teams[0].period3) : null,
                set4Value1: teams !== undefined ? (teams[0].period4) : null,
                set5Value1: teams !== undefined ? (teams[0].period5) : null,
                isWinner1: teams !== undefined ? (teams[0].winner == 1) : null,
                set1Value2: teams !== undefined ? (teams[1].period1) : null,
                set2Value2: teams !== undefined ? (teams[1].period2) : null,
                set3Value2: teams !== undefined ? (teams[1].period3) : null,
                set4Value2: teams !== undefined ? (teams[1].period4) : null,
                set5Value2: teams !== undefined ? (teams[1].period5) : null,
                isWinner2: teams !== undefined ? (teams[1].winner == 1) : null,
                raceName: matchName,
                circuitName: tournament.circuit_name !== undefined ? tournament.circuit_name.split('/').join(' / ').split('-').join(' - ') : null,
                circuitImgSrc: getImgURL(tournament.circuit_img),
                tournamentImgSrc: getImgURL(tournament.tournament_img),
                position1: teams !== undefined ? (teams[0].position) : 0,
                name1: teams !== undefined ? (teams[0].name) : '   ',
                position2: teams !== undefined ? (teams[1].position) : 0,
                name2: teams !== undefined ? (teams[1].name) : '   ',
                position3: teams !== undefined ? (teams.length > 2 ? teams[2].position : null) : 0,
                name3: teams !== undefined ? (teams.length > 2 ? teams[2].name : null) : '   ',
                position4: teams !== undefined ? (teams.length > 3 ? teams[3].position : null) : 0,
                name4: teams !== undefined ? (teams.length > 3 ? teams[3].name : null) : '   ',
                position5: teams !== undefined ? (teams.length > 4 ? teams[4].position : null) : 0,
                name5: teams !== undefined ? (teams.length > 4 ? teams[4].name : null) : '   '
            }
            tournamentElem.matches.push(matchElem)
        }
        return tournamentElem
    }

    function getSportElem(sport, model){
        var sportElem = {}
        switch (sport.sport_id){
            case 1: // football
                sportElem.sportName = "PIŁKA NOŻNA"
                break
            case 2: // basketball
                sportElem.sportName = "KOSZYKÓWKA"
                break
            case 4: // hockey
                sportElem.sportName = "HOKEJ"
                break
            case 5: // tenis
                sportElem.sportName = "TENIS"
                break
            case 6: // handball
                sportElem.sportName = "PIŁKA RĘCZNA"
                break
            case 11: // f1
                sportElem.sportName = "F1"
                break
                        default:
                                sportElem.sportName = "X"
                                break;

        }
        sportElem.sportId = sport.sport_id
        var tournaments = sport.entries.entry
        sportElem.tournaments = []
        for (var t in tournaments){
            var tournament = tournaments[t]
            var tournamentElem = getTournamentElem(tournament, true)
            sportElem.tournaments.push(tournamentElem)
        }
        return sportElem
    }

    function appendSport(sportElem, model){
        if (!model){
            model = getActiveListModel()
        }
        model.append(sportElem)
        JS.sportsIndexes["_"+ sportElem.sportId] = model.count - 1
    }

    function insertSportAsFirst(sportElem, model){
        if (!model){
            model = getActiveListModel()
        }
        model.insert(0, sportElem)
    }

    function fillData(data, info, apiParams, fromCache){
        dataLocked = true
        resultsCount = info.cnt;
        var activeList = getActiveList()
        var model = activeList.model
        if (!model){
            console.warning("list is not active yet")
            dataLocked = false
            return
        }

        if (page == 1){
            pageVisibleStart = 1
            pageVisibleEnd = 1
            cacheUp = false
            cacheDown = false
            JS.pageSportTournaments = {}
            JS.sportsIndexes = {}
            clearLists()
        }
        if (JS.pageSportTournaments["_"+ page] === undefined){
            JS.pageSportTournaments["_"+ page] = []
        }
        var cnt = 0
        for (var key in data){
            ++ cnt
            var sportElem = getSportElem(data[key], model)
            JS.pageSportTournaments["_"+ page].push(sportElem)
            appendSport(sportElem, model)
        }
        if (page >= 3){
            var pageKey = "_"+ (page - 2)
            //activeList.currentIndex = 0
            //var firstSection = activeList.currentItem
            //heightBefore = activeList.contentHeight
            //console.log("height: "+ heightBefore)
            activeList.positionViewAtIndex ( model.count - 1, ListView.End )
            for (var j = 0; j < JS.pageSportTournaments[pageKey].length; ++ j){
                remove(model, 0)
                /*
                for (var k = 0; k < JS.pageSportTournaments[pageKey][j].tournaments.length; ++ k){
                    if (firstSection.model.count > 0) firstSection.model.remove(0) // remove tournament
                }
                console.log("fillData "+ JS.pageSportTournaments[pageKey][j].tournaments.length +" tournaments removed")
                */
                /*
                if (firstSection.model.count === 0){
                    console.log("fillData first section is empty")
                    model.remove(0) // remove sport
                    activeList.currentIndex = 0
                    firstSection = activeList.currentItem
                    console.log("fillData first sport removed")
                }
                */
            }
            //heightAfter = activeList.contentHeight
            //activeList.contentY += heightAfter - heightBefore
            //console.log("height: "+ heightAfter)
            cacheUp = true
            pageVisibleStart ++
            activeList.positionViewAtIndex ( model.count - JS.pageSportTournaments["_"+ page].length - 1, ListView.End )
        }
        pageVisibleEnd = page
        cacheDown = false
        showList()
        pageLoaded = true
        dataLocked = false
    }

    function getActiveList(){
        return lists.activeList ? lists.activeList.list : undefined
    }

    function resetViewPosition(){
        getActiveList().contentY = 0;
    }

    function getSelectedTabIndex(){
        return topBar.selected;
    }

    function selectTab(ind){
        topBar.selectTab(ind);
    }

    function getScoresSelectedDate(){
        return topBar.getScoresSelectedDate();
    }

    function getSoonSelectedDate(){
        return topBar.getSoonSelectedDate();
    }

    function resetDatePickers(){
        topBar.resetDatePickers();
    }

    function clearDatePickers(){
        topBar.clearDatePickers();
    }

    function deselectAllTabs(){
        topBar.deselectAllTabs()
    }

    function remove(model, index){
        var tournaments = model.get(index).tournaments
        for (var j = 0; j < tournaments.count; ++ j){
            var matches = tournaments.get(j).matches
            matches.clear()
        }
        tournaments.clear()
        model.remove(index)
    }

    function clearList(model){
        for (var i = 0; i < model.count; ++ i){
            remove(model, i)
        }
        model.clear()
    }

    function clearLists(){
        cacheUp = false
        cacheDown = false
        clearList(liveList.model)
        clearList(scoresList.model)
        clearList(soonList.model)
    }

    function getActiveListModel(){
        return lists.activeList ? lists.activeList.model : undefined
    }
}
