import QtQuick 1.0
import "../../js/functions.js" as F
import "../../js/StatisticsAPI.js" as Stat

Item{

    property int selected: -1

    id: topBar
    anchors {top: parent.top; left: parent.left; right: parent.right}
    //color: parent.color
    height: 54 + datePickers.height
    z: 1000

    states: [
        State{
            name: "LIVE"
            when: liveTab.state === "SELECTED"
            PropertyChanges {target: datePickers; height: 0}
            StateChangeScript{
                script: Stat.send("aplikacja_livezone_symbian/na_zywo")
            }
        },
        State{
            name: "SCORES"
            when: scoresTab.state === "SELECTED"
            PropertyChanges{ target: datePickers; height: 65}
            PropertyChanges{ target: futureDatePicker; visible: false}
            PropertyChanges{ target: pastDatePicker; visible: true}
            StateChangeScript{
                script: Stat.send("aplikacja_livezone_symbian/wyniki")
            }
        },
        State{
            name: "SOON"
            when: soonTab.state === "SELECTED"
            PropertyChanges{ target: datePickers; height: 65}
            PropertyChanges{ target: futureDatePicker; visible: true}
            PropertyChanges{ target: pastDatePicker; visible: false}
            StateChangeScript{
                script: Stat.send("aplikacja_livezone_symbian/wkrotce")
            }
        }
    ]

    Item{
        id: menuBar
        anchors {top: parent.top; left: parent.left; right: parent.right; topMargin: 4; leftMargin: 10; rightMargin: 10}
        height: parent.height - datePickers.height
        Item{
            id: tabs
            width: parent.width * .85
            anchors {left: parent.left; top: parent.top}
            height: parent.height

            // three tabs
            TopBarTab{
                id: liveTab
                index: 0
                anchors {
                    top: parent.top
                    left: parent.left
                }
                text: "Na żywo"
            }
            TopBarTab{
                id: scoresTab
                index: 1
                anchors {
                    top: parent.top
                    left: liveTab.right; leftMargin: 1
                }
                text: "Wyniki"
            }
            TopBarTab{
                id: soonTab
                index: 2
                anchors {
                    top: parent.top
                    left: scoresTab.right; leftMargin: 1
                }
                text: "Wkrótce"
            }
        }

        // refresh button
        Item{
            height: 54
            width: 54
            anchors {right: parent.right; top: parent.top; left: tabs.right; leftMargin: 5;}
            Image{
                id: refreshImg
                source: ma.pressed ? "../../rsc/navi_arrow_black.png" : "../../rsc/navi_arrow_gray.png"
                anchors.centerIn: parent
            }
            MouseArea{
                id: ma
                anchors.fill: parent
                onClicked: {
                    resetEventsSearch();
                }
            }
        }
    }

    Item{
        id: datePickers
        anchors {left: parent.left; right: parent.right; top: menuBar.bottom; topMargin: 2}
        height: 0
        DatePicker{
            id: futureDatePicker
            anchors {left: parent.left; right: parent.right}
            visible: false
            soonMode: true
        }

        DatePicker{
            id: pastDatePicker
            anchors {left: parent.left; right: parent.right}
            visible: false
            soonMode: false
        }
    }

    function selectTab(ind){
        tabs.children[ind].select();
    }

    function getScoresSelectedDate(){
        return pastDatePicker.getSelectedDateStr();
    }

    function getSoonSelectedDate(){
        return futureDatePicker.getSelectedDateStr();
    }

    function resetDatePickers(){
        futureDatePicker.reset();
        pastDatePicker.reset();
    }

    function clearDatePickers(){
        futureDatePicker.clear();
        pastDatePicker.clear();
    }

    function deselectAllTabs(){
        for (var i = 0; i < tabs.children.length; ++i){
            if (tabs.children[i].state != "NORMAL") tabs.children[i].state = "NORMAL";
        }
        topBar.selected = -1;
    }
}
