import QtQuick 1.0
import "../../js/DB.js" as DB

Item {
    id: editFavouritesView
    width: container.width
    height: container.height
    //color: container.color
    x: - container.width * 1.5
    y: 0

    Item{
        id: emptyDataInfo
        anchors.fill: parent
        width: parent.width
        visible: false
        Text{
            color: "white"
            font {pixelSize: 18; bold: true}
            anchors.centerIn: parent
            wrapMode: Text.WordWrap
            text: "Brak ulubionych"
        }
    }

    Rectangle{
        width: grid.width
        height: 10
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        color: "grey"
        z: 1000
        Image{
            anchors.centerIn: parent
            source: "../../rsc/ch_up.gif"
        }
        visible: !grid.atYBeginning
    }

    ListView{
        property int firstIndexDrag: -1

        id: grid
        anchors {top: parent.top; bottom: bottomBelt.top; horizontalCenter: parent.horizontalCenter; bottomMargin: 1}
        width: parent.width * .6
        boundsBehavior: Flickable.StopAtBounds
        height: parent.height - 100
        model: ListModel{id: listModel}
        //highlight: FavouritesMenuItemHighlight{}
        //spacing: 1
        //interactive: false;
        clip: true
        delegate: EditFavouritesListItem{}
        /*
        states: [
            State{
                name: "SCROLL_UP"
                when: loc.currentId > -1 && loc.mouseY < 10
                PropertyChanges { target: grid; contentY: contentY - 1}
            },
            State{
                name: "SCROLL_DOWN"
                when: loc.currentId > -1 && loc.mouseY > grid.height - 10
                PropertyChanges { target: grid; contentY: contentY + 1}
            }
        ]
        */
        Timer{
            interval: 20
            repeat: true
            running: (loc.currentId > -1 && loc.mouseY > grid.height - 10 && grid.contentY < grid.contentHeight - grid.height)
            onTriggered: {
                grid.contentY += 15;
            }
        }
        Timer{
            interval: 20
            repeat: true
            running: (loc.currentId > -1 && loc.mouseY < 10 && grid.contentY > 0)
            onTriggered: {
                grid.contentY -= 15;
            }
        }
        MouseArea {
            property int currentId: -1                       // Original position in model
            property int newIndex                            // Current Position in model
            property int index: grid.indexAt(mouseX + grid.contentX, mouseY + grid.contentY) // Item underneath cursor
            id: loc
            anchors.fill: parent
            onPressAndHold: {
                currentId = listModel.get(newIndex = index).gridId;
                grid.interactive = false;
            }
            onReleased: {
                if (currentId === -1){
                    return
                }
                currentId = -1;
                var data = [];
                for (var i = 0; i < listModel.count; ++i){
                    var it = listModel.get(i);
                    data.push({
                        matchId: it.matchId,
                        tournamentId: it.tournamentId,
                        teamId: it.teamId,
                        catId: it.catId,
                        name: it.title,
                        disciplineId: it.disciplineId,
                        icon: it.icon
                    });
                }
                console.log(543)
                updateFavourites(data);
                console.log(345)
                grid.interactive = true;
            }
            onMousePositionChanged: {
                if (loc.currentId != -1 && index != -1 && index != newIndex)
                    listModel.move(newIndex, newIndex = index, 1);
            }
            onEntered: {
                var ind = grid.indexAt(mouseX + grid.contentX, mouseY + grid.contentY);
                grid.currentIndex = ind;
                var removeFromFavouritesIcon = grid.currentItem.children[1].children[2];
                if (mouseX >= removeFromFavouritesIcon.x &&
                        mouseX <= removeFromFavouritesIcon.x + removeFromFavouritesIcon.width){
                    grid.currentItem.children[1].children[2].children[1].visible = true
                }
            }
            onClicked: {
                var ind = grid.indexAt(mouseX + grid.contentX, mouseY + grid.contentY);
                grid.currentIndex = ind;
                var removeFromFavouritesIcon = grid.currentItem.children[1].children[2];
                if (mouseX >= removeFromFavouritesIcon.x &&
                        mouseX <= removeFromFavouritesIcon.x + removeFromFavouritesIcon.width){
                    var model = listModel.get(ind);
                    var matchId = model.matchId;
                    var tournamentId = model.tournamentId;
                    var teamId = model.teamId;
                    var catId = model.catId;
                    if (matchId !== 0){
                        DB.removeMatchFromFavourites(matchId);
                        var added = DB.checkMatchInFavourites(matchId);
                        if (!added){
                            dialog.showDialog('Mecz usunięty z ulubionych');
                        } else {
                            dialog.showDialog('Błąd usuwania z ulubionych');
                        }
                    /*} else if (!isNaN(tournamentId)){
                        removeTournamentFromFavourites(tournamentId);
                        var added = checkTournamentInFavourites(tournamentId);
                        if (!added){
                            dialog.showDialog('Turniej usunięty z ulubionych');
                        } else {
                            dialog.showDialog('Błąd usuwania z ulubionych');
                        }*/
                    } else if (teamId !== 0){
                        console.log(321)
                        DB.removeTeamFromFavourites(teamId);
                        console.log(123)
                        var added = DB.checkTeamInFavourites(tournamentId);
                        if (!added){
                            dialog.showDialog('Drużyna usunięta z ulubionych');
                        } else {
                            dialog.showDialog('Błąd usuwania z ulubionych');
                        }
                    } else if (catId !== 0){
                        DB.removeCategoryFromFavourites(catId);
                        var added = DB.checkCategoryInFavourites(catId);
                        if (!added){
                            dialog.showDialog('Kategoria usunięta z ulubionych');
                        } else {
                            dialog.showDialog('Błąd usuwania z ulubionych');
                        }
                    }
                    fillFavouritesForEdit();
                }
            }
        }

    }

    Rectangle{
        width: grid.width
        height: 10
        anchors.bottom: bottomBelt.top
        anchors.horizontalCenter: parent.horizontalCenter
        color: "grey"
        z: 1000
        Image{
            anchors.centerIn: parent
            source: "../../rsc/ch_down.gif"
        }
        visible: !grid.atYEnd
    }

    Item{
        id: bottomBelt
        anchors {left: parent.left; right: parent.right; bottom: parent.bottom;}
        height: itemHeight
        //color: parent.color
        Rectangle{
            id: okButton
            anchors {bottom: parent.bottom; horizontalCenter: parent.horizontalCenter; bottomMargin: 20}
            width: 100
            height: 25
            color: container.color
            border.color: "lightgrey"
            radius: 5
            Text{
                id: text
                anchors.centerIn: parent
                color: "lightgrey"
                font.pixelSize: defaultFontSize
                text: "OK"
            }
            MouseArea{
                anchors.fill: parent
                onPressed: {
                    var color = parent.color;
                    parent.color = text.color;
                    text.color = color;
                }
                onReleased: {
                    var color = parent.color;
                    parent.color = text.color;
                    text.color = color;
                }
                onClicked: {
                    fillFavourites();
                    container.state = "DEFAULT";
                }
            }
        }
    }

    function fillData(data){
        grid.model.clear();
        if (data.rows.length == 0){
            emptyDataInfo.visible = true;
            grid.visible = false;
        } else{
            emptyDataInfo.visible = false;
            grid.visible = true;
        }
        for (var i = 0; i < data.rows.length; ++i){
            var idd = parseInt(data.rows.item(i).ID)
            var type = data.rows.item(i).TYPE
            var matchId = 0, catId = 0, teamId = 0
            switch (type){
                case "M":
                    matchId = idd
                    break
                case "T":
                    teamId = idd
                    break
                case "C":
                    catId = idd
                    break
            }
            grid.model.append({
                title: data.rows.item(i).NAME,
                icon: matchId !== 0 ? getDisciplineIcon(data.rows.item(i).DISCIPLINE_ID) : (data.rows.item(i).ICON !== '' ? data.rows.item(i).ICON : ''),
                matchId: matchId,
                teamId: teamId,
                catId: catId,
                gridId: i,
                disciplineId: data.rows.item(i).DISCIPLINE_ID
            });
        }
    }
}
