import QtQuick 1.0
import "../navi"
import ".."

Item {
    id: favourites
    width: menuContainer.width
    height: parent.height
    //color: container.color
    z: 1

    Item{
        id: header
        anchors.top: parent.top
        width: parent.width
        height: itemHeight
        Text{
            anchors.centerIn: parent
            color: "lightgrey"
            font.pixelSize: 14
            text: "Ulubione"
        }
    }

    Item{
        id: emptyDataInfo
        anchors.top: header.bottom
        anchors.topMargin: 10
        width: parent.width
        height: 60
        visible: fModel.count == 0
        Text{
            color: "white"
            font {pixelSize: 14; bold: true}
            anchors.centerIn: parent
            wrapMode: Text.WordWrap
            text: "Brak ulubionych"
        }
    }
    FavouritesFooter{
        anchors{top: emptyDataInfo.bottom}
        id: fFooter
        visible: emptyDataInfo.visible
    }

    Rectangle{
        width: parent.width
        height: 10
        anchors.top: header.bottom
        color: "grey"
        z: 1000
        Image{
            anchors.centerIn: parent
            source: "../../rsc/ch_up.gif"
        }
        visible: favouritesView.visible && !favouritesView.atYBeginning
    }

    ListView{
        id: favouritesView


        //anchors.fill: parent
        anchors {left: parent.left; right: parent.right; top: header.bottom; bottom: parent.bottom}
        //anchors {left: parent.left; right: parent.right; top: emptyDataInfo.bottom}
        //height: 105 + fModel.count * itemHeight - emptyDataInfo.height
        visible: !emptyDataInfo.visible
        boundsBehavior: Flickable.StopAtBounds
        model: ListModel{id: fModel}
        highlight: FavouritesMenuItemHighlight{}
        footer: FavouritesFooter{}
        delegate: FavouritesDelegate{}
        ScrollBar{flickable: favouritesView; color: "white"}
        clip: true
        currentIndex: -1
        onCurrentIndexChanged: {
            if (currentIndex == -1){
                return
            }
            if (currentItem.matchID > 0){
                switch (currentItem.disciplineID){
                    case 1:
                        showFootballMatchDetail(currentItem.matchID, function(){onMatchEmptyData(currentItem.disciplineID, currentItem.matchID)});
                        break;
                    case 2:
                        showBasketballMatchDetail(currentItem.matchID, function(){onMatchEmptyData(currentItem.disciplineID, currentItem.matchID)});
                        break
                    case 4:
                        showHockeyMatchDetail(currentItem.matchID, function(){onMatchEmptyData(currentItem.disciplineID, currentItem.matchID)});
                        break;
                    case 5:
                        showTenisMatchDetail(currentItem.matchID, function(){onMatchEmptyData(currentItem.disciplineID, currentItem.matchID)});
                        break;
                    case 6:
                        showHandballMatchDetail(currentItem.matchID, function(){onMatchEmptyData(currentItem.disciplineID, currentItem.matchID)});
                        break;
                    case 11:
                        showF1RaceDetail(currentItem.matchID, function(){onMatchEmptyData(currentItem.disciplineID, currentItem.matchID)});
                        break;
                }
                return;
            }
            discipline_id = 0;
            category_id = currentItem.catID;
            tournament_id = 0; //currentItem.tournamentID;
            f_team_ids = "";
            team_id = currentItem.teamID;
            console.log(team_id)
            disciplinesMenu.setCurrentIndex(-1);
            categoriesMenu.setCurrentIndex(-1);
            tournamentsMenu.setCurrentIndex(-1);
            teamsMenu.setCurrentIndex(-1);
            showEventsView()
            getEvents()
        }
        Component.onCompleted: {console.log(contentHeight)}
    }
    Rectangle{
        width: parent.width
        height: 10
        anchors.bottom: parent.bottom
        color: "grey"
        z: 1000
        Image{
            anchors.centerIn: parent
            source: "../../rsc/ch_down.gif"
        }
        visible: favouritesView.visible && !favouritesView.atYEnd
    }

    transitions: Transition {
        NumberAnimation { properties: "x"; easing.type: Easing.InOutQuad }
    }

    function fillData(data){
        favouritesView.currentIndex = -1;
        favouritesView.model.clear();
        var teams = []
        var f1Included = false
        container.f_team_ids = ""
        container.f_f1_included = 0
        for (var i = 0; i < data.rows.length; ++i){
            var idd = parseInt(data.rows.item(i).ID)
            var type = data.rows.item(i).TYPE
            var matchId = 0, catId = 0, teamId = 0
            switch (type){
                case "M":
                    matchId = idd
                    break
                case "T":
                    teamId = idd
                    break
                case "C":
                    catId = idd
                    f1Included = true
                    break
            }
            var disciplineId = parseInt(data.rows.item(i).DISCIPLINE_ID)

            if (teamId !== 0){
                if (disciplineId === 11){
                    f1Included = true
                }
                teams.push(teamId)
            }
            favouritesView.model.append({
                title: data.rows.item(i).NAME,
                icon: matchId !== 0 ? getDisciplineIcon(data.rows.item(i).DISCIPLINE_ID) : (data.rows.item(i).ICON !== '' ? data.rows.item(i).ICON : ''),
                matchId: matchId,
                teamId: teamId,
                catId: catId,
                disciplineId: disciplineId

            });
        }

        if (teams.length > 0 || f1Included){
            var teamsStr = teams.join(",")
            var f1IncludedInt = f1Included ? 1 : 0
            eventsView.deselectAllTabs()
            var checked = container.checkFavouritesTeams(function(data){
               container.f_team_ids = teamsStr
               container.f_f1_included = f1IncludedInt
               if (parseInt(data[1].check) === 1){ // live
                    eventsView.selectTab(0)
               } else if (parseInt(data[0].check) === 1){ // scores
                    eventsView.selectTab(1)
               } else { // soon
                    eventsView.selectTab(2)
               }
            }, function(){eventsView.selectTab(2)}, onError, {
                team_ids: teamsStr, /*teams.length > 0 ? teams.join(',') : undefined*/
                f1: f1IncludedInt
            })
        } else {
            eventsView.showEmptyDataView()
        }
        favouritesView.currentIndex = -1;
    }

    function onMatchEmptyData(disciplineId, matchId){
        confirmDialog.showDialog(disciplineId === 11 ? 'Wyścig jest przestarzały.\nCzy chcesz go usunąć z ulubionych?' : 'Mecz jest przestarzały.\nCzy chcesz go usunąć z ulubionych?',
            function(){
                removeMatchFromFavourites(matchId);
                fillFavourites();
            },
            function(){});
    }
}
