Qt.include("MyTimerUtils.js")

function API(){}

API.prototype.LOG = 'API'

// API url
API.prototype.APIURL = 'http://lajt.onet.pl/livezone/api/api.html';
// ImgHost url
API.prototype.IMGURL = 'http://lajt.onet.pl/livezone/api/img/ico/';

// API result type
API.prototype.APITYPE = 'json';

API.prototype.mainElement = 'livescore';
API.prototype.entriesElement = 'entries';
API.prototype.entryElement = 'entry';
API.prototype.infoElement = 'info';
API.prototype.commentatorsElement = 'commentators';

API.prototype.requestSent = {};

API.prototype.getMainElement = function(data){
    return data[0][this.mainElement];
}

API.prototype.requests = {
    events: undefined,
    detal: undefined,
    disciplines: undefined,
    categories: undefined,
    tournaments: undefined,
    teams: undefined
}

API.prototype.timeout = 20000

// get entries element
API.prototype.getEntries = function(data){
    var entries = this.getMainElement(data)[this.entriesElement]
    if (entries){
        return entries[this.entryElement]
    }
    return null
}

// get info element
API.prototype.getInfo = function(data){
    return this.getMainElement(data)[this.infoElement];
}

// get commentators element
API.prototype.getCommentators = function(data){
    return this.getMainElement(data)[this.commentatorsElement];
}

// build a json string from object
API.prototype.toJSON = function(params){
    var result = '{';
    for (var key in params){
        result += '"'+ key +'":'+
                (typeof params[key] === 'number' ? params[key] : '"'+ params[key] +'"') +
                ',';
    }
    return result.substring(0, result.length - 1) + '}';
}

// get large icon url with given icon file name
API.prototype.getLargeImgURL = function(img){
    if (!img || img === ''){
        return '';
    }
    return this.IMGURL +'L/'+ img;
}

// get medium icon url with given icon file name
API.prototype.getMediumImgURL = function(img){
    if (!img || img === ''){
        return '';
    }
    return this.IMGURL +'M/'+ img;
}

// get small icon url with given icon file name
API.prototype.getSmallImgURL = function(img){
    if (!img || img === ''){
        return '';
    }
    return this.IMGURL +'S/'+ img;
}

// get extra small icon url with given icon file name
API.prototype.getXSImgURL = function(img){
    if (!img || img === ''){
        return '';
    }
    return this.IMGURL +'XS/'+ img;
}

// get icon url with given icon file name
API.prototype.getImgURL = function(img){
    if (!img || img === ''){
        return '';
    }
    return this.IMGURL + img;
}

// remove quots from a string
API.prototype.removeQuots = function(str){
    return str.replace(/&quot;/g, '');
}

API.prototype.logError = function(msg){
    console.log(this.LOG +' ERROR: '+ msg);
}

API.prototype.logWarning = function(msg){
    console.log(this.LOG +' WARNING: '+ msg);
}

API.prototype.getRequest = function(params){
    var xhr = new XMLHttpRequest;
    params = /*'?opalforcegateway=rtx0.int.dev.onet'+ */(params !== undefined && params !== null ? '?'+ params : '')
    var fullURL = this.APIURL + params;
    //console.log("\n\n####### url: "+ fullURL)
    //console.log(fullURL)
    xhr.open("GET", fullURL);
    xhr.url = fullURL;
    return xhr;
}

API.prototype.doRequest = function(onready, onemptydata, onerror, params, apiParams){
    if (this.requestSent[params]){
        return;
    }
    var request = this.getRequest(params);
    var self = this;
    var timer
    request.onreadystatechange = function(){
        if (request.readyState == XMLHttpRequest.DONE) {
            timer.stopTimer()
            //console.debug("\n\n####### status: "+ request.status + "\n####### size: "+ (request.responseText ? request.responseText.length : 0) +"\n####### url: "+ request.url +"\n####### response: "+ request.responseText)
            if (request.status === 200){
                request.handled = true
                var response = JSON.parse(request.responseText);
                var info = self.getInfo(response);
                var commentators = self.getCommentators(response);
                switch (info.status){
                    case 0: // OK
                        var data = self.getEntries(response);
                        onready(data, info, apiParams, commentators);
                        break;
                    case -1: // empty data
                        self.logWarning('Data is empty, desc: '+ info.desc +', params: '+ params);
                        if (typeof onemptydata === 'function') onemptydata();
                        break;
                    case -2: // fnc not exists
                    case -3: // data error
                    case -4: // params error
                    case -5: // fnc not defined
                        self.logError('Desc: '+ info.desc +', params: '+ params);
                        confirmDialog.showDialog('Wystąpił błąd podczas pobierania danych.\nCzy ponowić próbę?', function(){self.doRequest(onready, onemptydata, onerror, params, apiParams)}, function(){Qt.quit()})
                        //if (typeof onerror === 'function') onerror();
                        break;
                }
            } else {
                if (!request.noError){
                    if (request.timeout){
                        confirmDialog.showDialog('Przekroczono czas oczekiwania\nna odpowiedź serwera.\nCzy ponowić próbę?', function(){self.doRequest(onready, onemptydata, onerror, params, apiParams)}, function(){Qt.quit()})
                    } else {
                        confirmDialog.showDialog('Wystąpił błąd podczas pobierania danych.\nCzy ponowić próbę?', function(){self.doRequest(onready, onemptydata, onerror, params, apiParams)}, function(){Qt.quit()})
                    }

                }
            }
        }
        self.requestSent[params] = false;
    }

    request.send();
    timer = createAndLaunchTimer(container, self.timeout, function(){request.timeout = true; self.abortRequest(request)})
    request.timer = timer;
    this.requestSent[params] = true;
    return request
}

API.prototype.abortRequest = function(request, noError){
    if (!request.handled) {
        request.noError = noError === true
        request.abort()
        this.logWarning('Request aborted')
        if (request.timer !== undefined && typeof request.timer.stopTimer === 'function'){
            request.timer.stopTimer()
        }
    }
}

// main function for retreiving data
API.prototype.getData = function(funcName, onready, onemptydata, onerror, addParams){
    var params = 'fnc='+ funcName +'&type='+ this.APITYPE;
    params += (typeof addParams === 'object' ? '&params='+ JSON.stringify(addParams) : ''); //this.toJSON(addParams) : '');
    return this.doRequest(onready, onemptydata, onerror, params, addParams);
}

API.prototype.getDisciplines = function(onready, onemptydata, onerror, addParams){
    if (this.requests.disciplines){
        this.abortRequest(this.requests.disciplines, true)
        this.requests.disciplines = undefined
    }
    this.requests.disciplines = this.getData('getSportsList', onready, onemptydata, onerror, addParams);
}

API.prototype.getCategories = function(onready, onemptydata, onerror, addParams){
    if (typeof addParams.id !== 'number'){
        this.logError('getCategories: id is required!');
        return;
    }
    if (this.requests.categories){
        this.abortRequest(this.requests.categories, true)
        this.requests.categories = undefined
    }
    this.requests.categories = this.getData('getCategoriesList', onready, onemptydata, onerror, addParams);
}

API.prototype.getTournaments = function(onready, onemptydata, onerror, addParams){
    if (typeof addParams.id !== 'number'){
        this.logError('getTournaments: id is required!');
        return;
    }
    if (this.requests.tournaments){
        this.abortRequest(this.requests.tournaments, true)
        this.requests.tournaments = undefined
    }
    this.requests.tournaments = this.getData('getTournamentsList', onready, onemptydata, onerror, addParams);
}

API.prototype.getTeams = function(onready, onemptydata, onerror, addParams){
    if (typeof addParams.id !== 'number'){
        this.logError('getTeams: id is required!');
        return;
    }
    if (this.requests.teams){
        this.abortRequest(this.requests.teams, true)
        this.requests.teams = undefined
    }
    this.requests.teams = this.getData('getTeamsList', onready, onemptydata, onerror, addParams);
}

API.prototype.getDetal = function(onready, onemptydata, onerror, addParams){
    if (typeof addParams.id !== 'number'){
        this.logError('getDetal: id is required!');
        return;
    }
    if (this.requests.detal){
        this.abortRequest(this.requests.detal, true)
        this.requests.detal = undefined
    }
    this.requests.detal = this.getData('getDetal', onready, onemptydata, onerror, addParams);
}

API.prototype.checkEvents = function(onready, onemptydata, onerror, addParams){
    eventsView.showLoadView()
    this.getData('getMatchListByStatusAndDateCheck', onready, onemptydata, onerror, addParams);
}

API.prototype.getEvents = function(onready, onemptydata, onerror, addParams){
    if (this.requests.events){
        this.abortRequest(this.requests.events, true)
        this.requests.events = undefined
    }
    this.requests.events = this.getData('getMatchListByStatusAndDate', onready, onemptydata, onerror, addParams);
}

API.prototype.checkFavouritesTeams = function(onready, onemptydata, onerror, addParams){
    eventsView.showLoadView()
    this.getData('getMatchListFavoriteByStatusAndDateCheck', onready, onemptydata, onerror, addParams);
}

API.prototype.getEventsForFavourites = function(onready, onemptydata, onerror, addParams){
    if (this.requests.events){
        this.abortRequest(this.requests.events, true)
        this.requests.events = undefined
    }
    this.requests.events = this.getData('getMatchListFavoriteByStatusAndDate', onready, onemptydata, onerror, addParams);
}

API.prototype.fillMaxFavouritesCount = function(){
    this.getData('getFavoriteLimit', function(data, info){container.maxFavourites = info.limit; console.log("#### FAVOURITES LIMIT: "+ container.maxFavourites)});
}

// new instance
var api = new API();
