import QtQuick 1.0
import "content"
import "content/menu"
import "content/favourites"
import "content/navi"
import "content/events"
import "content/matchDetail"
import "content/settings"
import "js/API.js" as API
import "js/StatisticsAPI.js" as Stat
import "js/DB.js" as DB
import "js/functions.js" as F
import "js/vars.js" as VARS

// main window
Rectangle{

    id: container
    width: 640
    height: 360
    color: "#000000"

    Image{
        width: parent.width
        height: parent.height
        source: "rsc/wynik_tlo_cale.png"
        fillMode: Image.PreserveAspectCrop
    }

    // default font size
    property int defaultFontSize: 12
    property int itemHeight: container.height * 0.1667

    property int dataLimitDay

    // currently selected discipline (sport_id)
    property int discipline_id;
    // currently selected category
    property int category_id;
    // currently selected tournament
    property int tournament_id;
    // currently selected team
    property int team_id;
    // id of a match that is currently viewed
    property string match_id;
    // name of a match that is currently viewed
    property string match_name;

    // discipline selected via favourites
    property int f_discipline_id;
    // category selected via favourites
    property int f_category_id;
    // torunament selected via favourites
    property int f_tournament_id;
    // team selected via favourites
    property int f_team_id;
    // team ids from favourites
    property string f_team_ids: ""
    // f1 search included for events
    property int f_f1_included: 0


    property int maxFavourites

    state: "SPLASH"

    states: [
        /*
        // web view after ad click
        State{
            name: "WEB"
            PropertyChanges { target: views; x: 0 }
            PropertyChanges { target: splashView; visible: false }
        },
        */
        // splash view

        // main view state
        State{
            name: "DEFAULT"
            PropertyChanges { target: views; x: 0}
            PropertyChanges { target: splashView; source: "" }
            StateChangeScript{
                script: banner.show()
            }
            //PropertyChanges { target: defaultView; visible: true}
        },
        // edit favourites view
        State{
            name: "EDIT_FAVOURITES"
            StateChangeScript{
                script: fillFavouritesForEdit()
            }
            //PropertyChanges { target: defaultView; visible: false}
            PropertyChanges { target: views; x: - container.width}
            PropertyChanges { target: splashView; source: "" }
        },
        State{
            name: "SPLASH"
            PropertyChanges { target: views; x: - container.width * 2 }
            PropertyChanges { target: splashView; source: "rsc/splash.png" }
        }
    ]

    transitions: Transition {
        // animation to change views
        NumberAnimation { properties: "x"; easing.type: Easing.InOutQuad }
    }

    // dialog item
    Dialog{
        id: dialog
        z: 100
    }

    ConfirmDialog{
        id: confirmDialog
        z: 100
    }

    Row {
        id: views
        height: parent.height
        /*
        Item {
            id: webViewItem
            width: container.width
            height: container.height
            Flickable{
                id: webViewFlick
                width: parent.width
                height: parent.height
                contentWidth: Math.max(parent.width,webView.width)
                contentHeight: Math.max(parent.height,webView.height)
                WebView {
                    id: webView
                    transformOrigin: Item.TopLeft
                    preferredWidth: webViewFlick.width
                    preferredHeight: webViewFlick.height
                    settings.javascriptEnabled: false
                    contentsScale: 1
                }
            }
            Image{
                anchors {
                    right: parent.right; rightMargin: 5
                    top: parent.top; topMargin: 5
                }
                source: "rsc/close-button.gif"
                z: 10000
                MouseArea{
                    anchors.fill: parent
                    onClicked: container.state = "DEFAULT"
                }
            }
        }
        */

        Item{
            id: defaultView
            width: container.width
            height: container.height
            Item{
                id: menuContainer
                width:  parent.width * .33
                anchors.top: parent.top; anchors.left: parent.left
                height: parent.height
                Item{
                    id: logoItem
                    anchors {
                        top: parent.top
                        left: parent.left
                        right: parent.right
                    }
                    height: 29
                    Image {
                        anchors.centerIn: parent
                        source: "rsc/logo_livezone150.png"

                    }
                }

                //state: "MENU"
                // left view (menu) states
                states: [
                    // menu state (default)
                    State{
                        name: "MENU"
                        //PropertyChanges { target: favourites; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: favouritesMenu; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: settings; x: - menuContainer.width * 1.5}
                        PropertyChanges { target: menus; x: 0}
                        PropertyChanges { target: container; f_team_ids: ""}
                        StateChangeScript {
                            script: {
                                container.discipline_id = 0
                                container.category_id = 0
                                container.tournament_id = 0
                                container.team_id = 0
                                naviBar.hideNavis();
                                //eventsView.resetDatePickers()
                                disciplinesMenu.setCurrentIndex(-1)
                                resetEventsSearch();
                                showEventsView();
                            }
                        }
                        PropertyChanges { target: menu; x: 0 }
                    },
                    // favourites item state. It apears when we click favourites at the main menu
                    State{
                        name: "FAVOURITES"
                        PropertyChanges { target: menus; x: - menuContainer.width - 5}
                        //PropertyChanges { target: settings; x: - menuContainer.width * 1.5}
                        StateChangeScript {
                            script: {
                                container.discipline_id = 0
                                container.category_id = 0
                                container.tournament_id = 0
                                container.team_id = 0
                                favouritesDisciplinesMenu.children[0].currentIndex = -1
                                eventsView.clearDatePickers();
                                fillFavourites();
                                naviBar.showNavi(2);
                                showEventsView();
                            }
                        }
                        //PropertyChanges { target: favourites; x: 0 }
                    },

                    // favourites disciplines menu
                    State{
                        name: "FAVOURITES_MENU"
                        //PropertyChanges { target: favourites; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: menu; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: settings; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: favouritesMenu; x: 0}
                        PropertyChanges { target: menus; x: - menuContainer.width * 2 - 10}
                        PropertyChanges { target: container; f_team_ids: ""}
                        StateChangeScript{
                            script: {favouritesDisciplinesMenu.children[0].currentIndex = 0; showFavouritesRightView(); favouritesMenu.currentIndex = 0}
                        }
                    },
                    // settings view
                    State{
                        name: "SETTINGS"
                        //PropertyChanges { target: favourites; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: menu; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: favouritesMenu; x: - menuContainer.width * 1.5}
                        //PropertyChanges { target: settings; x: 0}
                        PropertyChanges { target: menus; x: - menuContainer.width * 3 - 15}
                        PropertyChanges { target: container; f_team_ids: ""}
                        StateChangeScript{
                            script: naviBar.showNavi(2)
                        }
                    }

                ]
                transitions: Transition {
                    NumberAnimation { properties: "x"; easing.type: Easing.InOutQuad }
                }

                Row{
                    id: menus
                    anchors {top: logoItem.bottom; bottom: naviBar.top}

                    ListView{
                        property int prevIndex: 0
                        property int prevContentX

                        id: menu
                        orientation: ListView.Horizontal
                        width: menuContainer.width
                        height: parent.height
                        //width: parent.width
                        //height: parent.height - naviBar.height
                        //x: 0
                        y: 0
                        snapMode: ListView.SnapOneItem
                        boundsBehavior: Flickable.StopAtBounds
                        spacing: 2
                        currentIndex: 0
                        interactive: false
                        model: VisualItemModel{
                            DisciplinesMenu {id: disciplinesMenu}
                            CategoriesMenu {id: categoriesMenu}
                            TournamentsMenu {id: tournamentsMenu}
                            TeamsMenu {id: teamsMenu}
                        }

                        onCurrentIndexChanged: {
                            if (currentIndex === -1){
                                return
                            }
                            //eventsView.resetDatePickers();
                            var indexDecreased = prevIndex > currentIndex;
                            if (currentIndex == 0){
                                naviBar.hideNavis();
                                category_id = 0;
                                tournament_id = 0;
                                team_id = 0;
                                categoriesMenu.setCurrentIndex(-1);
                                tournamentsMenu.setCurrentIndex(-1);
                                teamsMenu.setCurrentIndex(-1);
                                categoriesMenu.clear()
                                tournamentsMenu.clear()
                                teamsMenu.clear()
                            } else if (currentIndex == 1){
                                naviBar.showNavi(2);
                                tournament_id = 0;
                                team_id = 0;
                                tournamentsMenu.setCurrentIndex(-1);
                                teamsMenu.setCurrentIndex(-1);
                                tournamentsMenu.clear()
                                teamsMenu.clear()
                            } else if (currentIndex == 2){
                                naviBar.showNavi(3);
                                team_id = 0;
                                teamsMenu.setCurrentIndex(-1);
                                teamsMenu.clear()
                                if (discipline_id == 11){
                                    teamsMenu.showMenuNotAvailableInfo();
                                } else {
                                    teamsMenu.hideMenuNotAvailableInfo();
                                }
                            } else if (currentIndex == 3){
                                naviBar.showNavi(4);
                            }
                            if (indexDecreased){
                                resetEventsSearch();
                            }
                            prevIndex = currentIndex;
                            showEventsView();
                        }

                        onContentXChanged: {
                            if (moving){
                                var index = indexAt(contentX + 2, 0);
                                var index2 = indexAt(contentX + menu.width - 2, 0);
                                if (index != -1 && index == index2 && index != currentIndex){
                                    currentIndex = index;
                                }
                            }
                        }
                        //Behavior on contentX { NumberAnimation { id: contentXAnimation; duration: 400; easing.type: Easing.InOutQuad } }
                    }

                    Item{ // spacer
                        width: 5
                        height: parent.height
                    }

                    Favourites{
                        id: favourites

                        //anchors {top: parent.top; bottom: naviBar.top}
                        //x: - menuContainer.width * 1.5

                    }

                    Item{ // spacer
                        width: 5
                        height: parent.height
                    }

                    ListView{
                        id: favouritesMenu
                        orientation: ListView.Horizontal
                        width: menuContainer.width
                        height: parent.height
                        //height: parent.height - naviBar.height
                        //x: - menuContainer.width * 1.5
                        y: 0
                        snapMode: ListView.SnapOneItem
                        boundsBehavior: Flickable.StopAtBounds
                        spacing: 1
                        interactive: false
                        model: VisualItemModel{
                            FavouritesDisciplinesMenu {id: favouritesDisciplinesMenu}
                            FavouritesCategoriesMenu {id: favouritesCategoriesMenu}
                            FavouritesTournamentsMenu {id: favouritesTournamentsMenu}
                            FavouritesTeamsMenu {id: favouritesTeamsMenu}
                        }
                        currentIndex: -1
                        onCurrentIndexChanged: {
                            if (currentIndex == 0){
                                var ci = favouritesDisciplinesMenu.children[0].currentItem;
                                if (ci){
                                    favouritesRightView.showLoadView()
                                    getCategories(ci.discipline_ID, fillCategoriesInFavourites, function(){favouritesRightView.showEmptyDataInfo()});
                                }
                                favouritesTournamentsMenu.children[0].model.clear()
                                naviBar.showNavi(2);
                            } else if (currentIndex == 1){
                                var ci = favouritesCategoriesMenu.children[0].currentItem;
                                if (ci){
                                    favouritesRightView.showLoadView()
                                    getTournaments(ci.category_ID, fillTournamentsInFavourites, function(){favouritesRightView.showEmptyDataInfo()});
                                }
                                naviBar.showNavi(3);
                            } else if (currentIndex == 2){
                                var ci = favouritesTournamentsMenu.children[0].currentItem;
                                if (ci){
                                    favouritesRightView.showLoadView()
                                    getTeams(ci.tournament_ID, fillTeamsInFavourites, function(){favouritesRightView.showEmptyDataInfo()});
                                }
                                naviBar.showNavi(4);
                            }

                        }
                    }

                    Item{ // spacer
                        width: 5
                        height: parent.height
                    }

                    Settings{
                        id: settings
                        width: menuContainer.width
                        height: parent.height
                        //height: parent.height - naviBar.height
                    }
                }


                NaviBar{
                    id: naviBar
                    //context: menu
                }
            }

            Rectangle{
                property variant previous;
                property variant current;

                id: rightViewContainer
                color: "#efefef"
                anchors {top: parent.top; left: menuContainer.right; bottom: parent.bottom; right: parent.right; leftMargin: 2}
                radius: 5
                z: 2
                FavouritesRightView{
                    id: favouritesRightView
                }

                FootballMatchDetail{
                    id: footballMatchDetail
                }

                BasketballMatchDetail{
                    id: basketballMatchDetail
                }

                HockeyMatchDetail{
                    id: hockeyMatchDetail
                }

                HandballMatchDetail{
                    id: handballMatchDetail
                }

                TenisMatchDetail{
                    id: tenisMatchDetail
                }

                F1RaceDetail{
                    id: f1RaceDetail
                }

                EventsView{
                    id: eventsView
                }

                Image{
                    id: banner
                    objectName: "banner"
                    z: 2000
                    anchors {bottom: parent.bottom; horizontalCenter: parent.horizontalCenter}
                    width: bannerModel.status === XmlListModel.Ready ? bannerModel.get(0).imgWidth : 100
                    height: bannerModel.status === XmlListModel.Ready ? bannerModel.get(0).imgHeight : 100
                    smooth: true
                    //fillMode: Image.PreserveAspectFit
                    visible: false
                    source: bannerModel.status === XmlListModel.Ready ? bannerModel.get(0).imgSrc : ""
                    MouseArea{
                        anchors.fill: parent
                        enabled: bannerModel.status === XmlListModel.Ready ? bannerModel.get(0).type === "url" : false
                        onClicked: {
                            bannerCloser.stop()
                            banner.visible = false
                            //urlOpener.open(bannerModel.get(0).url)
                            Qt.openUrlExternally( bannerModel.get(0).url )
                        }
                    }
                    Image{
                        anchors {
                            right: parent.right; rightMargin: 5
                            top: parent.top; topMargin: 5
                        }
                        source: "rsc/close-button.gif"
                        z: 10000
                        visible: bannerModel.status === XmlListModel.Ready ? bannerModel.get(0).close === "YES" : false
                        MouseArea{
                            anchors.fill: parent
                            onClicked: banner.visible = false
                        }
                    }
                    Timer{
                        id: bannerCloser
                        running: bannerModel.status === XmlListModel.Ready
                        repeat: false
                        interval: bannerModel.status === XmlListModel.Ready ? bannerModel.get(0).delay * 1000 : 9999999
                        onTriggered: {banner.visible = false}
                    }
                    XmlListModel {
                        id: bannerModel
                        //source: "http://lajt1234onet.beta.onet.pl/ad_test/ad.html?site=LAJT_SYMBIAN&area=LIVEZONE&display=ADLAJT_B&size="+ rightViewContainer.width +"&height="+ container.height/2 +"&ver=3"
                        source: "http://lajt.onet.pl/ad_mob/ad.html?site=LAJT_SYMBIAN&area=LIVEZONE&display=ADLAJT_B&size="+ rightViewContainer.width +"&height="+ container.height/2 +"&ver=3"
                        query: "/ad"

                        XmlRole { name: "delay"; query: "config/@delay/number()" }
                        XmlRole { name: "close"; query: "config/@close/string()" }
                        XmlRole { name: "type"; query: "config/@type/string()" }
                        XmlRole { name: "imgSrc"; query: "img/@src/string()" }
                        XmlRole { name: "imgWidth"; query: "img/@width/number()" }
                        XmlRole { name: "imgHeight"; query: "img/@height/number()" }
                        XmlRole { name: "url"; query: "link/@url/string()" }
                    }

                    function show(){
                        if (!banner.visible){
                            bannerModel.reload()
                            banner.visible = true
                        }
                    }
                }
            }
        }


        EditFavouritesView{
            id: editFavouritesView
        }

        Splash{
            id: splashView
        }
    }


    Component.onCompleted: {
        API.api.fillMaxFavouritesCount()
        var favsExist = DB.favouritesExist()
        if (favsExist){
            menuContainer.state = "FAVOURITES"
        } else {
            showEventsView();
            eventsView.showLoadView()
            var checked = API.api.checkEvents(function(data){
               if (parseInt(data[1].check) === 1){ // live
                    eventsView.selectTab(0)
               } else if (parseInt(data[0].check) === 1){ // scores
                    eventsView.selectTab(1)
               } else { // soon
                    eventsView.selectTab(2)
               }
            }, function(){eventsView.selectTab(2)}, onError, {})
            //eventsView.selectTab(0);
        }
        getDisciplines();
        Stat.send("aplikacja_livezone_symbian");
    }


    // functions

    function onEmptyData(){
    }

    function onError(){
    }

    function getEntries(data){
        return API.api.getEntries(data);
    }

    function getImgURL(img){
        return API.api.getImgURL(img);
    }

    function getSmallImgURL(img){
        return API.api.getSmallImgURL(img);
    }

    function getMediumImgURL(img){
        return API.api.getMediumImgURL(img);
    }

    function getLargeImgURL(img){
        return API.api.getLargeImgURL(img);
    }

    function getFootballDetal(emptyDataCallback){
        footballMatchDetail.showLoader()
        API.api.getDetal(footballMatchDetail.fillData, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {id: footballMatchDetail.idd});
    }

    function getBasketballDetal(emptyDataCallback){
        basketballMatchDetail.showLoader()
        API.api.getDetal(basketballMatchDetail.fillData, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {id: basketballMatchDetail.idd});
    }

    function getHockeyDetal(emptyDataCallback){
        hockeyMatchDetail.showLoader()
        API.api.getDetal(hockeyMatchDetail.fillData, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {id: hockeyMatchDetail.idd});
    }

    function getHandballDetal(emptyDataCallback){
        handballMatchDetail.showLoader()
        API.api.getDetal(handballMatchDetail.fillData, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {id: handballMatchDetail.idd});
    }

    function getTenisDetal(emptyDataCallback){
        tenisMatchDetail.showLoader()
        API.api.getDetal(tenisMatchDetail.fillData, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {id: tenisMatchDetail.idd});
    }

    function getF1Detal(emptyDataCallback){
        f1RaceDetail.showLoader()
        API.api.getDetal(f1RaceDetail.fillData, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {id: f1RaceDetail.idd});
    }

    function addMatchToFavourites(disciplineId){
        DB.addMatchToFavourites(match_id, match_name, disciplineId, null);
    }

    function addTournamentToFavourites(id, name, icon){
        DB.addTournamentToFavourites(id, name, f_discipline_id, icon);
    }

    function addTeamToFavourites(id, name, icon){
        DB.addTeamToFavourites(id, name, f_discipline_id, icon);
    }

    function removeMatchFromFavourites(matchId){
        DB.removeMatchFromFavourites(matchId ? matchId : match_id);
    }

    function removeTournamentFromFavourites(id){
        DB.removeTournamentFromFavourites(id);
    }

    function removeTeamFromFavourites(id){
        DB.removeTeamFromFavourites(id);
    }

    function checkMatchInFavourites(matchId){
        return DB.checkMatchInFavourites(matchId ? matchId : match_id);
    }

    function checkTournamentInFavourites(tournamentId){
        return DB.checkTournamentInFavourites(tournamentId);
    }

    function checkTeamInFavourites(teamId){
        return DB.checkTeamInFavourites(teamId);
    }

    function fillFavourites(){
        var data = DB.getFavourites();
        favourites.fillData(data);
    }

    function getDisciplineIcon(id){
        return VARS.DISCIPLINES_ICONS['_'+ id];
    }

    function getDisciplines(callback){
        disciplinesMenu.showLoadingView();
        API.api.getDisciplines(callback ? callback : fillDisciplines, onEmptyData, onError, {
            //order: 1,
            //sort: 1,
            pglen: 0,
            pgnum: 1,
            active: 1,
            limit_day: dataLimitDay
        });
    }

    function getCategories(disciplineId, callback, emptyDataCallback){
        categoriesMenu.showLoadingView();
        API.api.getCategories(callback ? callback : fillCategories, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {
            id: disciplineId,
            //order: 1,
            //sort: 1,
            pglen: 0,
            pgnum: 1,
            active: 1,
            limit_day: dataLimitDay
        });
    }

    function getTournaments(categoryId, callback, emptyDataCallback){
        tournamentsMenu.showLoadingView();
        API.api.getTournaments(callback ? callback : fillTournaments, emptyDataCallback ? emptyDataCallback : onEmptyData, onError, {
            id: categoryId,
            //order: 1,
            //sort: 1,
            pglen: 0,
            pgnum: 1,
            active: 1,
            limit_day: dataLimitDay
        });
    }

    function getTeams(tournamentId, callback, emptyDataCallback){
        teamsMenu.showLoadingView();
        API.api.getTeams(callback ? callback : fillTeams, emptyDataCallback ? emptyDataCallback : teamsMenu.showMenuNotAvailableInfo, onError, {
            id: tournamentId,
            //order: 1,
            //sort: 1,
            pglen: 0,
            pgnum: 1,
            active: 1,
            limit_day: dataLimitDay
        });
    }

    function fillDisciplines(data){
        disciplinesMenu.clear();
        favouritesDisciplinesMenu.children[0].model.clear();
        disciplinesMenu.append({ // favourites button
            name: "Ulubione",
            src: "../../rsc/ulubione.png",
            disciplineId: -1
        });
        for (var i in data){
            var imgURL = getDisciplineIcon(data[i].id);

            var model = {
                name: API.api.removeQuots(data[i].name),
                src: imgURL ? imgURL : "",
                disciplineId: data[i].id
            };
            disciplinesMenu.append(model);

            favouritesDisciplinesMenu.children[0].model.append({
                   title: API.api.removeQuots(data[i].name),
                   icon: imgURL ? imgURL : "",
                   disciplineId: data[i].id
            });

        }
        /*
        disciplinesMenu.append({ // settings button
            name: "Ustawienia",
            src: "../../rsc/settings.png",
            disciplineId: -1
        });
        */
        disciplinesMenu.setCurrentIndex(- 1);
        //favouritesDisciplinesMenu.children[0].currentIndex = 0;
        disciplinesMenu.hideLoadingView();
    }

    function fillCategories(data){
        categoriesMenu.clear();
        for (var i in data){
            var model = {
                name: API.api.removeQuots(data[i].name),
                src: (data[i].img !== undefined && data[i].img !== '') ? API.api.getMediumImgURL(data[i].img) : '',
                categoryId: data[i].id
            };
            categoriesMenu.append(model);
        }
        categoriesMenu.setCurrentIndex(- 1);
        categoriesMenu.hideLoadingView();
    }

    function fillTournaments(data){
        tournamentsMenu.clear();
        for (var i in data){
            var model = {
                name: API.api.removeQuots(data[i].name),
                src: (data[i].img !== undefined && data[i].img !== '') ? API.api.getMediumImgURL(data[i].img) : '',
                tournamentId: data[i].id
            };
            tournamentsMenu.append(model);
        }
        tournamentsMenu.setCurrentIndex(- 1);
        tournamentsMenu.hideLoadingView();
    }

    function fillTeams(data){
        teamsMenu.clear();
        for (var i in data){
            var model = {
                name: API.api.removeQuots(data[i].name),
                src: (data[i].img !== undefined && data[i].img !== '') ? API.api.getMediumImgURL(data[i].img) : '',
                teamId: data[i].id
            };
            teamsMenu.append(model);
        }
        teamsMenu.setCurrentIndex(- 1);
        teamsMenu.hideLoadingView();
    }

    function hideAllRightViews(){
        for (var i = 0; i < rightViewContainer.children.length; ++i){
            if (rightViewContainer.children[i].objectName !== "banner" && rightViewContainer.children[i].opacity === 1){
                rightViewContainer.children[i].opacity = 0;
            }
        }
    }

    function showPreviousRightView(){
        var previous = rightViewContainer.previous;
        hideAllRightViews();
        previous.opacity = 1;
    }

    function showFavouritesRightView(){
        hideAllRightViews();
        favouritesRightView.opacity = 1;
    }

    function showFootballMatchDetail(matchId, emptyDataCallback){
        hideAllRightViews();
        if (matchId){
            footballMatchDetail.idd = matchId
            getFootballDetal(emptyDataCallback);
        }
        footballMatchDetail.opacity = 1;
    }

    function showBasketballMatchDetail(matchId, emptyDataCallback){
        hideAllRightViews();
        if (matchId){
            basketballMatchDetail.idd = matchId
            getBasketballDetal(emptyDataCallback);
        }
        basketballMatchDetail.opacity = 1;
    }

    function showHockeyMatchDetail(matchId, emptyDataCallback){
        hideAllRightViews();
        if (typeof(matchId) !== undefined && matchId !== null){
            hockeyMatchDetail.idd = matchId
            getHockeyDetal(emptyDataCallback);
        }
        hockeyMatchDetail.opacity = 1;
    }

    function showHandballMatchDetail(matchId, emptyDataCallback){
        hideAllRightViews();
        if (matchId){
            handballMatchDetail.idd = matchId
            getHandballDetal(emptyDataCallback);
        }
        handballMatchDetail.opacity = 1;
    }

    function showTenisMatchDetail(matchId, emptyDataCallback){
        hideAllRightViews();
        if (matchId){
            tenisMatchDetail.idd = matchId
            getTenisDetal(emptyDataCallback);
        }
        tenisMatchDetail.opacity = 1;
    }

    function showF1RaceDetail(matchId, emptyDataCallback){
        hideAllRightViews();
        if (matchId){
            f1RaceDetail.idd = matchId
            getF1Detal(emptyDataCallback);
        }
        f1RaceDetail.opacity = 1;
    }

    function showEventsView(){
        hideAllRightViews();
        eventsView.opacity = 1;
    }

    function fillDisciplinesInFavourites(data){
        favouritesDisciplinesMenu.children[0].model.clear();
        for (var i in data){
            var imgURL = getDisciplineIcon(data[i].id);
            var model = {
                title: API.api.removeQuots(data[i].name),
                icon: imgURL ? imgURL : "",
                disciplineId: data[i].id
            };
            favouritesDisciplinesMenu.children[0].model.append(model);
        }
        favouritesDisciplinesMenu.children[0].currentIndex = 0;
    }

    function fillCategoriesInFavourites(data){
        favouritesCategoriesMenu.children[0].model.clear();
        favouritesRightView.clearCategories();
        for (var i in data){
            var model = {
                title: API.api.removeQuots(data[i].name),
                icon: (data[i].img !== undefined && data[i].img !== '') ? API.api.getMediumImgURL(data[i].img) : '',
                categoryId: data[i].id
            };
            favouritesCategoriesMenu.children[0].model.append(model);
            favouritesRightView.appendCategory(model);
        }
        favouritesRightView.showCategories();
        favouritesRightView.hideLoadView()
    }

    function fillTournamentsInFavourites(data){
        favouritesTournamentsMenu.children[0].model.clear();
        favouritesRightView.clearTournaments();
        for (var i in data){
            var model = {
                title: API.api.removeQuots(data[i].name),
                icon: (data[i].img !== undefined && data[i].img !== '') ? API.api.getMediumImgURL(data[i].img) : '',
                tournamentId: data[i].id
            };
            favouritesTournamentsMenu.children[0].model.append(model);
            favouritesRightView.appendTournament(model);
        }
        favouritesRightView.showTournaments();
        favouritesRightView.hideLoadView()
    }

    function fillTeamsInFavourites(data){
        favouritesTeamsMenu.children[0].model.clear();
        favouritesRightView.clearTeams();
        for (var i in data){
            var model = {
                title: API.api.removeQuots(data[i].name),
                icon: (data[i].img !== undefined && data[i].img !== '') ? API.api.getMediumImgURL(data[i].img) : '',
                teamId: data[i].id
            };
            favouritesTeamsMenu.children[0].model.append(model);
            favouritesRightView.appendTeam(model);
        }
        favouritesRightView.showTeams();
        favouritesRightView.hideLoadView()
    }

    function fillFavouritesForEdit(){
        var data = DB.getFavourites();
        editFavouritesView.fillData(data);
    }

    function updateFavourites(data){
        DB.updateFavourites(data);
    }

    function getEvents(){

        if (eventsView.page == 1){
            eventsView.showLoadView();
        } else {
            eventsView.showSmallLoadView();
        }

        var tab = eventsView.getSelectedTabIndex()
        var status = undefined;
        var date = undefined;
        if (tab == 0){
            status = 1;
        } else if (tab == 1){
            status = 0;
            date = eventsView.getScoresSelectedDate();
        } else if (tab == 2){
            status = 2;
            date = eventsView.getSoonSelectedDate();
        }

        if (menuContainer.state === "FAVOURITES" && container.team_id === 0 && container.category_id === 0){
            if (container.f_team_ids !== "" || container.f_f1_included === 1){
                API.api.getEventsForFavourites(eventsView.fillData, eventsView.page == 1 ? eventsView.showEmptyDataView : eventsView.showList, onError, {
                    team_ids: container.f_team_ids,
                    f1: container.f_f1_included,
                    date: date ? date : undefined,
                    status: status,
                    //order: 1,
                    //sort: 1,
                    pglen: eventsView.pageLength,
                    pgnum: eventsView.page,
                    active: 1,
                    limit_day: 8
                }); return;
            } else {
                eventsView.showEmptyDataView(); return;
            }

        }

        API.api.getEvents(eventsView.fillData, eventsView.page == 1 ? eventsView.showEmptyDataView : eventsView.showList, onError, {
            sport_id: container.discipline_id ? container.discipline_id : undefined,
            category_id: container.category_id ? container.category_id : undefined,
            tournament_id: container.tournament_id ? container.tournament_id : undefined,
            team_id: container.team_id ? container.team_id : undefined,
            date: date ? date : undefined,
            status: status,
            //order: 1,
            //sort: 1,
            pglen: eventsView.pageLength,
            pgnum: eventsView.page,
            active: 1,
            limit_day: 8
        });

    }

    function checkFavouritesTeams(onready, onemptydata, onerror, addParams){
        eventsView.showLoadView()
        API.api.checkFavouritesTeams(onready, onemptydata, onerror, addParams)
    }

    function resetEventsSearch(){
        eventsView.page = 1;
        eventsView.pageVisibleStart = 1
        eventsView.pageVisibleEnd = 1
        eventsView.cacheUp = false
        eventsView.cacheDown = false
        eventsView.pageLoaded = true
        eventsView.resultsCount = -1;
        eventsView.resetViewPosition();
        getEvents();
    }

    function dump(obj){
        var str = '\n'
        for (var key in obj){
            str += '\n'+ key +': '+ obj[key]
        }
        console.log(str)
    }
}

